@@ -2,6 +2,8 @@ import io
 import json
 import random
 import logging
+from importlib_metadata import version, PackageNotFoundError
+import click
 from scrapy.crawler import CrawlerProcess
 from rich.console import Console
 from rich.logging import RichHandler
@@ -75,15 +77,80 @@ def get_quote_from_json_stream(stream):
     return quotes[quote_selector]
 
 
-def main():
+@click.command()
+@click.option(
+    '--rich-text/--no-rich-text',
+    ' /-R',
+    help='Rich Text support',
+    default=True
+)
+@click.option(
+    '--show-tags/--no-show-tags',
+    ' /-T',
+    help='Show or Hide quote tags',
+    default=True
+)
+@click.option(
+    '--show-link/--no-show-link',
+    ' /-L',
+    help='Show or Hide quote link',
+    default=True
+)
+@click.option(
+    '--log-level',
+    '-l',
+    help='Set log level',
+    type=click.Choice(
+        [
+            'CRITICAL',
+            'ERROR',
+            'WARNING',
+            'INFO',
+            'DEBUG',
+            'NOTSET'
+        ],
+        case_sensitive=False
+    ),
+    default='CRITICAL'
+)
+@click.option(
+    '--version',
+    '-v',
+    'show_version',
+    help='Print version information and quit',
+    is_flag=True
+)
+def main(
+    rich_text=True,
+    show_tags=True,
+    show_link=True,
+    log_level="CRITICAL",
+    show_version=False
+):
+    """Feed your brain with the best random quotes from multiple web portals"""
     print_styles = {
         "text": "italic",
         "author": "bold"
     }
 
-    logger = init_logging(logging.CRITICAL)
+    if not rich_text:
+        print_styles = {
+            "text": "",
+            "author": ""
+        }
+
+    logger = init_logging(log_level)
     console = Console()
 
+    if show_version:
+        quoted_version = 'master'
+        try:
+            quoted_version = version('quoted')
+        except PackageNotFoundError:
+            logger.debug("PackageNotFoundError: quoted version not found")
+        console.print('Quoted version %s' % quoted_version)
+        exit()
+
     spider = get_spider()
     do_crawl(spider)
 
@@ -91,12 +158,19 @@ def main():
         quote = get_quote_from_json_stream(bytestream)
 
         console.print("")
-        console.print("“%s”" % quote["text"], style=print_styles["text"])
+        console.print(
+            "“%s”" % quote["text"],
+            style=print_styles["text"],
+            highlight=False
+        )
         console.print("―― %s" % quote["author"], style=print_styles["author"])
         console.print("")
-        console.print("tags: %s" % ', '.join(quote["tags"]))
-        console.print("link: %s" % quote["url"])
-        console.print("")
+        if show_tags:
+            console.print("tags: %s" % ', '.join(quote["tags"]))
+        if show_link:
+            console.print("link: %s" % quote["url"])
+        if show_tags or show_link:
+            console.print("")
         console.print("© %s" % spider.name)
         console.print("")
         console.print("Powered by quoted")
